# -*- coding: utf8 -*-

from django.contrib.messages import constants as msg_constants
from os.path import realpath, dirname, join
import sys

root_dir = dirname(dirname(__file__))

import locale

locale.setlocale(locale.LC_ALL, "fr_FR.UTF-8")

EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"

DEBUG = True

ADMINS = (("Webmasters", "portail@bde.inp-toulouse.fr"),)

MANAGERS = ADMINS

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": join(root_dir, "portail.db"),
    },
}

# Accès au LDAP
LDAP_ACCESS_SECRET = {
    "cri": {
        "uri": "ldap://ldapmaster.enseeiht.fr",
        "base": "dc=n7,dc=fr",
        "accounts": {},
    },
    "principal": {
        "uri": "ldap://discover.bde.inp-toulouse.fr",
        "base": "dc=etu-inpt,dc=fr",
        "accounts": {
            "root": ("cn=Manager,dc=etu-inpt,dc=fr", None),
            "consult": (
                "uid=client-consult,ou=scripts,ou=inp-net,o=inp,dc=etu-inpt,dc=fr",
                "i3THzAiX",
            ),
            "manager": (
                "uid=client-manager,ou=scripts,ou=inp-net,o=inp,dc=etu-inpt,dc=fr",
                "LGRou0Pj",
            ),
        },
    },
}

MYSQL_HOST = "localhost"

MYSQL_ROOT_PASSWORD = "copernic"

APPEND_SLASH = False

DEFAULT_FROM_EMAIL = "INP-net <inp-net@bde.inp-toulouse.fr>"
NOREPLY_EMAIL = "INP-net <no-reply@bde.inp-toulouse.fr>"
EMAIL_HOST = "smtp.bde.inp"

EMAIL_LOCA7 = "loca7@bde.enseeiht.fr"
EMAIL_NEWS = "admin-news"
ECOBOX_MAIL = {"n7": "bdd@bde.enseeiht.fr", "ENSAT": "ecobox@bde.ensat.fr"}

MESSAGE_STORAGE = "django.contrib.messages.storage.session.SessionStorage"
MESSAGE_TAGS = {
    msg_constants.DEBUG: "",
    msg_constants.SUCCESS: "alert-success",
    msg_constants.INFO: "alert-info",
    msg_constants.WARNING: "alert-warning",
    msg_constants.ERROR: "alert-danger",
}

TIME_ZONE = "Europe/Paris"

LANGUAGE_CODE = "fr-fr"

SITE_ID = 1

USE_I18N = True
USE_L10N = True

# Absolute path to the directory that holds media.
MEDIA_ROOT = join(root_dir, "media")

# URL that handles the media served from MEDIA_ROOT.
MEDIA_URL = "/media/"
STATIC_URL = "/static/"

# Path to a writable directory used by modules to store persistent data
MISC_DATA_ROOT = join(root_dir, "misc_data")

CLUB_MEDIA_FOLDER = join(root_dir, "media", "blog_clubs", "{ident}")
CLUB_MEDIA_URL = "{url_ecole}/media/blog_clubs/{ident}/"

# Make this unique, and don't share it with anybody.
SECRET_KEY = "r*u1vo^9hud16a6&c4m(!64^%!pp^574d^yi-3jai!28*s)0-$"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [
            join(root_dir, "templates"),
        ],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.contrib.auth.context_processors.auth",
                "django.template.context_processors.debug",
                "django.template.context_processors.i18n",
                "django.template.context_processors.media",
                "django.template.context_processors.static",
                "django.template.context_processors.request",
                "django.contrib.messages.context_processors.messages",
                "context_processors.common_processors",
            ],
            "libraries": {
                "gest_inscriptions_tags": "gestion.inscriptions.tags",
            },
            "debug": DEBUG,
        },
    },
]

LOGIN_REDIRECT_URL = "/"
LOGOUT_REDIRECT_URL = "/"
LOGIN_URL = "/auth/login/"

if DEBUG:
    TEMPLATES[0]["OPTIONS"]["string_if_invalid"] = "[[INVALID]]"

MIDDLEWARE = (
    "django.middleware.common.CommonMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django_cas_ng.middleware.CASMiddleware",
    "portailuser.middleware.EcoleMiddleware",
    "pages.middleware.PagesMiddleware",  # /!\ doit être après EcoleMiddleware
    "portailuser.middleware.FirstLoginChangePasswd",
)

ROOT_URLCONF = "portail.urls"

TEST_RUNNER = "django.test.runner.DiscoverRunner"

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.staticfiles",
    "django.contrib.messages",
    "django.forms",
    "imagekit",
    "bootstrap_datepicker_plus",
    "captcha",
    "accueil",
    "annuaire",
    "attachments",
    "bootstrap4",
    "bbcode",  # Pour le JS des widgets
    "club",
    "edt",
    "formations",
    "gestion",  # Pour le JS des widgets
    "gestion.accueil",
    "gestion.aliases",
    "gestion.clubs",
    "gestion.groupes",
    "gestion.inscriptions",
    "gestion.logs",
    "gestion.permissions",
    "gestion.eleves",
    "gestion.frappe",
    "infos_reseau",
    "live",
    "logement",
    "pages",
    "portailuser",
    "reinit_mdp",
    "sondages",
    "anniversaire",
    "evenements",
    "ecobox",
    "covoiturage",
    "inscriptions",
    "frappe",
    "django_tables2",
    "django_cas_ng",
]

APP_WIDGETS = [
    ("infos_reseau", "État réseau INP-net"),
    # ("accueil", "Demande de parrainage"),
    # ("edt", "Emploi du temps"),
    # ("formations", "Formations"),
    ("anniversaire", "Anniversaires"),
    # ("evenements", "Prochains événements"),
    # ("blogs_favoris", "Mes blogs favoris"),
]

CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.filebased.FileBasedCache",
        "LOCATION": "/tmp/abc/django_cache_portail",
    }
}

FRAPPE_MAX_UPLOAD_SIZE = 20 * 1024 * 1024  # 20 Mo

ECOLE_PAR_ENV = False

LIVE_AUTH_ALLOWED_IPS = ["127.0.0.1", "147.127.161.142"]

# Accès à l’annuaire sans authentification
ALLOWED_ADDRS = [
    "147.127",
    "192.168",
    "10.147.127",  # VPN OpenVPN
    "10.147.128",  # VPN tinc
    "91.224.148.251",  # Tux
    "127.0.0.1",
]

ALLOWED_HOSTS = [".localhost", "127.0.0.1", "[::1]"]

CORRESP_HOTES = {
    "n7-dev.localhost:8000": "n7",
    "ensat-dev.localhost:8000": "ensat",
    "a7-dev.localhost:8000": "a7",
    "enm-dev.localhost:8000": "enm",
}
# Par défaut: inp

FORM_RENDERER = "django.forms.renderers.TemplatesSetting"

# Attention, ces adresses ne doivent pas contenir de / final
URLS_SITES = (
    "www-dev.localhost:8000",
    "n7-dev.localhost:8000",
    "ensat-dev.localhost:8000",
    "a7-dev.localhost:8000",
    "enm-dev.localhost:8000",
)

EMAIL_BDE = ("bde.inp-toulouse.fr", "bde.enseeiht.fr", "bde.ensat.fr", "bde.ensiacet.fr", "bde.inp-toulouse.fr")

# Ne pas partager ces identifiants, ils sont réservés uniquement au portail, merci !
EDT_AUTH = {"n7": ("net7", "Cb1FoN7"), "a7": ("edta7", ""), "ensat": ("edtensat", "")}
EDT_DEC_HORAIRE = {}

# Pour déterminer ces identifiants (qui changent chaque année), se connecter sur edt.inp-toulouse.fr
# avec les logins ci-dessus et regarder les requêtes XHR qui passent dans le
# navigateur. Une requête vers WebClientServiceProxy va avoir une réponse de ce format:
# //OK[1,["[3]{\"40\"\"A7 2018-2019\"{\"32\"\"SC Reservation 2019-2025\"{\"23\"\"A7 2019-2020\""],0,7]
# Ceci permet de faire le lien entre un nom de projet (par exemple “A7 2019-2020”) et un ID (ici, 23)

EDT_PROJECT_ID = {"a7": "23", "ensat": "35", "n7": "20"}

DONNEES_INSCRIPT_AUTONOME = None
INSCRIPT_PHOTOS_SRC = "backend/media/photos/source"
INSCRIPT_PHOTOS_DST = "backend/media/photos/dest"

AUTHENTICATION_BACKENDS = ("portailuser.auth_backend.PortailAuthBackend",)

DJANGO_TABLES2_TEMPLATE = "django_tables2/bootstrap4.html"

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "filters": {"require_debug_false": {"()": "django.utils.log.RequireDebugFalse"}},
    "handlers": {
        "mail_admins": {
            "level": "ERROR",
            "filters": ["require_debug_false"],
            "class": "django.utils.log.AdminEmailHandler",
            "include_html": True,
        },
        "stderr": {
            "level": "DEBUG",
            "filters": [],
            "class": "logging.StreamHandler",
        },
    },
    "loggers": {
        "django.request": {
            "handlers": ["mail_admins"],
            "level": "ERROR",
            "propagate": False,
        },
        "edt.views": {
            "handlers": ["mail_admins"],
            "level": "WARNING",
            "propagate": False,
        },
        "django.db.backends": {
            "level": "ERROR",
            "handlers": ["stderr"],
            "propagate": False,
        },
    },
}

# Temps d'édition page en minutes

EDITION_TIME = 30

SOUTH_MIGRATION_MODULES = {
    "captcha": "captcha.south_migrations",
}

# avertissement pour l'annuaire
SEUIL_AVERTISSEMENT = 15
SEUIL_ALERTE_ADMIN = 50
SEUIL_BLOQUE_ADMIN = 10

DOMAINES_INSTITUTIONNELS = [
    "enseeiht.fr",
    "ensiacet.fr",
    "ensat.fr",
    "enm.fr",
    "meteo.fr",
    "enm-toulouse.fr",
    "inp-n7.fr",
    "inp-a7.fr",
    "inp-ensat.fr",
    "inp-toulouse.fr",
    "toulouse-inp.fr",
]

DOMAINES_INP_NET = [
    "inp-net.eu.org",
    "inpt.fr",
    "bde.inp-toulouse.fr",
    "bde.enseeiht.fr",
    "bde.ensat.fr",
    "bde.ensiacet.fr",
]

# Noms de domaines qui doivent être acceptés pour les réinitialisations de mots de passe
DOMAINES_REINIT_MDP = [
    "etu.enseeiht.fr",
    "etu.inp-n7.fr",
    "etu.ensiacet.fr",
    "etu.inp-a7.fr",
    "etu.ensat.fr",
    "etu.inp-ensat.fr",
    "meteo.fr",
    "enm.fr",
    "enm-toulouse.fr",
    "etu.inp-toulouse.fr",
    "etu.toulouse-inp.fr",
]

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"

CAS_SERVER_URL = "https://cas.dev.inpt.fr"
CAS_VERSION = "3"
CAS_CREATE_USER = True
CAS_FORCE_SSL_SERVICE_URL = True

try:
    fd = open(join(root_dir, "portail", "local_settings.py"), "r")
    exec(fd.read())
    fd.close()
except IOError:
    pass
else:
    if DEBUG:
        import types
        import importlib

        mod = types.ModuleType(
            "portail.local_settings",
            doc="Fake module to " "have Django watch local_settings for changes",
        )
        mod.__file__ = realpath(join(root_dir, "portail", "local_settings.py"))
        mod.__spec__ = importlib.machinery.ModuleSpec("portail.local_settings", None, origin=mod.__file__)
        mod.__spec__.has_location = True
        sys.modules["portail.local_settings"] = mod
        del types, mod, importlib

FILE_UPLOAD_PERMISSIONS = 0o640
